# STX Language

STX is a markup language for creating documents.
It is designed to be simple enough to be easily read and written but at the 
same time powerful enough to allow creating complex documents.

Please visit https://stx-lang.github.io/docs/ to read the complete documentation.
